@@ -1,27 +1,13 @@
 /*
-    Copyright (c) 2016 Klarälvdalens Datakonsult AB
+    SPDX-FileCopyrightText: 2016 Klarälvdalens Datakonsult AB
 
-    This library is free software; you can redistribute it and/or modify it
-    under the terms of the GNU Library General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or (at your
-    option) any later version.
-
-    This library is distributed in the hope that it will be useful, but WITHOUT
-    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-    License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to the
-    Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-    02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "cryptopage.h"
 #include "dialog.h"
 #include "identity.h"
 #include "accountwizard_debug.h"
-#include "key.h"
 #include "transport.h"
 
 #include <Libkleo/DefaultKeyFilter>
@@ -48,7 +34,6 @@
 
 #include <QFileDialog>
 #include <QEventLoopLocker>
-#include <QPointer>
 
 class KeyGenerationJob : public QObject
 {
@@ -86,7 +71,7 @@ Q_SIGNALS:
 private Q_SLOTS:
     void onObjectSetupFinished(SetupObject *obj)
     {
-        if (Transport *transport = qobject_cast<Transport *>(obj)) {
+        if (auto *transport = qobject_cast<Transport *>(obj)) {
             mTransportId = transport->transportId();
         }
     }
