@@ -1,21 +1,8 @@
 /*
-    Copyright (c) 2009 Volker Krause <vkrause@kde.org>
-    Copyright (c) 2010 Tom Albers <toma@kde.org>
+    SPDX-FileCopyrightText: 2009 Volker Krause <vkrause@kde.org>
+    SPDX-FileCopyrightText: 2010 Tom Albers <toma@kde.org>
 
-    This library is free software; you can redistribute it and/or modify it
-    under the terms of the GNU Library General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or (at your
-    option) any later version.
-
-    This library is distributed in the hope that it will be useful, but WITHOUT
-    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-    License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to the
-    Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-    02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "dialog.h"
@@ -27,7 +14,6 @@
 #include "loadpage.h"
 #include "global.h"
 #include "dynamicpage.h"
-#include "setupmanager.h"
 #include "servertest.h"
 #include "setuppage.h"
 #include "cryptopage.h"
@@ -56,7 +42,7 @@ Dialog::Dialog(QWidget *parent)
     const bool showPersonalDataPage = Global::typeFilter().size() == 1 && Global::typeFilter().at(0) == KMime::Message::mimeType();
     if (showPersonalDataPage) {
         // todo: don't ask these details based on a setting of the desktop file.
-        PersonalDataPage *pdpage = new PersonalDataPage(this);
+        auto *pdpage = new PersonalDataPage(this);
         addPage(pdpage, i18n("Provide personal data"));
         connect(pdpage, &PersonalDataPage::manualWanted, this, &Dialog::slotManualConfigWanted);
         if (!Global::assistant().isEmpty()) {
@@ -64,13 +50,13 @@ Dialog::Dialog(QWidget *parent)
         }
 
         if (!GpgME::checkEngine(GpgME::OpenPGP)) {
-            CryptoPage *cryptoPage = new CryptoPage(this);
+            auto *cryptoPage = new CryptoPage(this);
             addPage(cryptoPage, i18n("Secure your Communication"));
         }
     }
 
     if (Global::assistant().isEmpty()) {
-        TypePage *typePage = new TypePage(this);
+        auto *typePage = new TypePage(this);
         connect(typePage->treeview(), &QAbstractItemView::doubleClicked, this, &Dialog::slotNextPage);
 #ifndef ACCOUNTWIZARD_NO_GHNS
         connect(typePage, &TypePage::ghnsWanted, this, &Dialog::slotGhnsWanted);
@@ -79,7 +65,7 @@ Dialog::Dialog(QWidget *parent)
         setAppropriate(mTypePage, false);
 
 #ifndef ACCOUNTWIZARD_NO_GHNS
-        ProviderPage *ppage = new ProviderPage(this);
+        auto *ppage = new ProviderPage(this);
         connect(typePage, &TypePage::ghnsWanted, ppage, &ProviderPage::startFetchingData);
         connect(ppage->treeview(), &QAbstractItemView::doubleClicked, this, &Dialog::slotNextPage);
         connect(ppage, &ProviderPage::ghnsNotWanted, this, &Dialog::slotGhnsNotWanted);
@@ -88,7 +74,7 @@ Dialog::Dialog(QWidget *parent)
 #endif
     }
 
-    LoadPage *loadPage = new LoadPage(this);
+    auto *loadPage = new LoadPage(this);
     mLoadPage = addPage(loadPage, i18n("Loading Assistant"));
     setAppropriate(mLoadPage, false);
     loadPage->exportObject(this, QStringLiteral("Dialog"));
@@ -96,7 +82,7 @@ Dialog::Dialog(QWidget *parent)
     loadPage->exportObject(new ServerTest(this), QStringLiteral("ServerTest"));
     connect(loadPage, &LoadPage::aboutToStart, this, &Dialog::clearDynamicPages);
 
-    SetupPage *setupPage = new SetupPage(this);
+    auto *setupPage = new SetupPage(this);
     mLastPage = addPage(setupPage, i18n("Setting up Account"));
     mSetupManager->setSetupPage(setupPage);
 
